@@ -1,3 +1,3 @@
-from .scraper import Scraper
+from .scraper import Scraper,ScraperWrapper
 from .dispatcher import Dispatcher
 from .globalshutdown import GlobalShutdown
